==> cristalise-kernel-5.7.1-test-sources.jar: org/cristalise/kernel/test/process/LauncherTest.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.test.process;

import java.util.Properties;

import org.cristalise.kernel.process.AbstractMain;
import org.cristalise.kernel.process.resource.BadArgumentsException;
import org.junit.Test;

public class LauncherTest {

    private String[] standardArgs() {
        String[] args = new String[8];
        args[0] = "-logLevel";
        args[1] = "0";
        args[2] = "-logFile";
        args[3] = "target/testlog.txt";
        args[4] = "-config";
        args[5] = LauncherTest.class.getResource("/server.conf").getPath();
        args[6] = "-connect";
        args[7] = LauncherTest.class.getResource("/test.clc").getPath();

        return args;
    }

    @Test
    public void testValidC2KArgs() throws Exception {
        Properties props = AbstractMain.readC2KArgs(standardArgs());

        assert "XMLClusterStorage".equals(props.get("ClusterStorage")) : "Config file properties not loaded";
        assert "1553".equals(props.get("ItemServer.Proxy.port")) : "Connect file properties not loaded";
    }

    @Test
    public void testWrongConfigFileName() throws Exception {
        String[] args = standardArgs();
        args[5] = "filenotfound";
        try {
            AbstractMain.readC2KArgs(args);
            assert false : "Invalid connect file not detected";
        }
        catch (BadArgumentsException ex) {}
    }

    @Test
    public void testWrongConnectFileName() throws Exception {
        String[] args = standardArgs();
        args[7] = "alsonotfound";
        try {
            AbstractMain.readC2KArgs(args);
            assert false : "Invalid connect file not detected";
        }
        catch (BadArgumentsException ex) {}
    }

    @Test
    public void testMissingConnectArg() throws Exception {
        String[] args = new String[2];
        args[0] = "-config";
        args[1] = LauncherTest.class.getResource("/server.conf").getPath();
        try {
            AbstractMain.readC2KArgs(args);
            assert false : "Missing connect file not detected";
        }
        catch (BadArgumentsException ex) {}
    }

    @Test
    public void testMissingConfigArg() throws Exception {
        String[] args = new String[2];
        args[0] = "-connect";
        args[1] = LauncherTest.class.getResource("/test.clc").getPath();
        try {
            AbstractMain.readC2KArgs(args);
            assert false : "Missing config file not detected";
        }
        catch (BadArgumentsException ex) {}
    }
}

==> cristalise-kernel-6.0.0-test-sources.jar: org/cristalise/kernel/test/process/LauncherTest.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.test.process;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import java.util.Properties;

import org.cristalise.kernel.process.AbstractMain;
import org.cristalise.kernel.process.resource.BadArgumentsException;
import org.junit.Test;

public class LauncherTest {

    private String[] standardArgs() {
        String[] args = new String[4];
        args[0] = "-config";
        args[1] = LauncherTest.class.getResource("/server.conf").getPath();
        args[2] = "-connect";
        args[3] = LauncherTest.class.getResource("/test.clc").getPath();

        return args;
    }

    @Test
    public void testValidC2KArgs() throws Exception {
        Properties props = AbstractMain.readC2KArgs(standardArgs());

        assertEquals("Config file properties not loaded",  "XMLClusterStorage", props.get("ClusterStorage"));
        assertEquals("Connect file properties not loaded", "localhost",         props.get("ItemServer.name"));
    }

    @Test
    public void testWrongConfigFileName() throws Exception {
        String[] args = standardArgs();
        args[1] = "filenotfound";
        try {
            AbstractMain.readC2KArgs(args);
            fail("Invalid config file not detected");
        }
        catch (BadArgumentsException ex) {}
    }

    @Test
    public void testWrongConnectFileName() throws Exception {
        String[] args = standardArgs();
        args[3] = "alsonotfound";
        try {
            AbstractMain.readC2KArgs(args);
            fail("Invalid connect file not detected");
        }
        catch (BadArgumentsException ex) {}
    }

    @Test
    public void testMissingConnectArg() throws Exception {
        String[] args = new String[2];
        args[0] = "-config";
        args[1] = LauncherTest.class.getResource("/server.conf").getPath();
        try {
            AbstractMain.readC2KArgs(args);
            fail("Missing connect file not detected");
        }
        catch (BadArgumentsException ex) {}
    }

    @Test
    public void testMissingConfigArg() throws Exception {
        String[] args = new String[2];
        args[0] = "-connect";
        args[1] = LauncherTest.class.getResource("/test.clc").getPath();
        try {
            AbstractMain.readC2KArgs(args);
            fail("Missing config file not detected");
        }
        catch (BadArgumentsException ex) {}
    }
}
